agentle.agents.a2a.tasks.task\_send\_params
===========================================

.. automodule:: agentle.agents.a2a.tasks.task_send_params

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      Any
      BaseModel
      Message
      PushNotificationConfig
      TaskSendParams
   